{
  pkgs,
  lib,
  config,
  ...
}:

{
  sops.secrets.restic-repo = {
    sopsFile = lib.mkDefault (./. + "/../../secrets/restic/${config.networking.hostName}-repo.yaml");
  };

  sops.secrets.restic-base-password = {
    sopsFile = lib.mkDefault (./. + "/../../secrets/restic/${config.networking.hostName}-base-password.yaml");
  };

  sops.secrets.restic-env = {
    sopsFile = ../../secrets/restic_client.env;
    format = "dotenv";
  };

  services.restic.backups = {
    base = {
      exclude = [
        "/var/cache"
        "/var/lib/lxcfs"
      ];
      initialize = true;
      passwordFile = config.sops.secrets.restic-base-password.path;
      repositoryFile = config.sops.secrets.restic-repo.path;
      environmentFile = config.sops.secrets.restic-env.path;
      paths = [
        "/etc"
        "/var"
      ];
      timerConfig = {
        OnCalendar = "00:00";
        RandomizedDelaySec = "6h";
      };
      pruneOpts = [
        "--keep-daily 2"
        "--keep-weekly 2"
        "--keep-monthly 2"
        "--keep-yearly 1"
      ];
    };
  };
}
